@@ -6,7 +6,7 @@ import logging
 import pkgutil
 import re
 from pathlib import Path
-from typing import Any, List
+from typing import Any
 
 import attr
 
@@ -122,6 +122,7 @@ class _Options:
         type=str,
         default="1",
         validator=attr.validators.matches_re(r"[123456]"),
+        converter=attr.converters.optional(str),
         metadata={
             "doc": """\
                 A number: for Markdown changelog files, this is the heading
@@ -352,6 +353,8 @@ class Config:
                 except KeyError:
                     pass
                 else:
+                    if callable(attrdef.converter):
+                        val = attrdef.converter(val)
                     setattr(self._options, attrdef.name, val)
 
     def resolve_value(self, value: str) -> str:
@@ -434,7 +437,7 @@ class Config:
         return value
 
 
-def convert_list(val: str) -> List[str]:
+def convert_list(val: str) -> list[str]:
     """
     Convert a string value from a config into a list of strings.
 
